import * as React from 'react';
import { FormControlState } from './FormControl.types';
/**
 * @ignore - internal component.
 */
declare const FormControlContext: React.Context<FormControlState | undefined>;
export { FormControlContext };
