import { UseFormControlContextReturnValue } from './FormControl.types';
/**
 *
 * Demos:
 *
 * - [Form Control](https://mui.com/base-ui/react-form-control/#hook)
 *
 * API:
 *
 * - [useFormControlContext API](https://mui.com/base-ui/react-form-control/hooks-api/#use-form-control-context)
 */
export declare function useFormControlContext(): UseFormControlContextReturnValue | undefined;
