import { PolymorphicComponent } from '../utils/PolymorphicComponent';
import { BadgeTypeMap } from './Badge.types';
/**
 *
 * Demos:
 *
 * - [Badge](https://mui.com/base-ui/react-badge/)
 *
 * API:
 *
 * - [Badge API](https://mui.com/base-ui/react-badge/components-api/#badge)
 */
declare const Badge: PolymorphicComponent<BadgeTypeMap<{}, "span">>;
export { Badge };
