import { UseButtonParameters, UseButtonReturnValue } from './useButton.types';
/**
 *
 * Demos:
 *
 * - [Button](https://mui.com/base-ui/react-button/#hook)
 *
 * API:
 *
 * - [useButton API](https://mui.com/base-ui/react-button/hooks-api/#use-button)
 */
export declare function useButton(parameters?: UseButtonParameters): UseButtonReturnValue;
