import { NumberInputReducerAction, NumberInputState } from './useNumberInput.types';
export declare function numberInputReducer(state: NumberInputState, action: NumberInputReducerAction): NumberInputState;
