import { UseBadgeParameters, UseBadgeReturnValue } from './useBadge.types';
/**
 *
 * Demos:
 *
 * - [Badge](https://mui.com/base-ui/react-badge/#hook)
 *
 * API:
 *
 * - [useBadge API](https://mui.com/base-ui/react-badge/hooks-api/#use-badge)
 */
export declare function useBadge(parameters: UseBadgeParameters): UseBadgeReturnValue;
