import { OverridableComponent } from '@mui/types';
import { NumberInputTypeMap } from './NumberInput.types';
/**
 *
 * Demos:
 *
 * - [Number Input](https://mui.com/base-ui/react-number-input/)
 *
 * API:
 *
 * - [NumberInput API](https://mui.com/base-ui/react-number-input/components-api/#number-input)
 */
declare const NumberInput: OverridableComponent<NumberInputTypeMap<{}, "div">>;
export { NumberInput };
