import { UseOptionParameters, UseOptionReturnValue } from './useOption.types';
/**
 *
 * Demos:
 *
 * - [Select](https://mui.com/base-ui/react-select/#hooks)
 *
 * API:
 *
 * - [useOption API](https://mui.com/base-ui/react-select/hooks-api/#use-option)
 */
export declare function useOption<Value>(params: UseOptionParameters<Value>): UseOptionReturnValue;
