import { PolymorphicComponent } from '../utils';
import { TabPanelTypeMap } from './TabPanel.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/)
 *
 * API:
 *
 * - [TabPanel API](https://mui.com/base-ui/react-tabs/components-api/#tab-panel)
 */
declare const TabPanel: PolymorphicComponent<TabPanelTypeMap<{}, "div">>;
export { TabPanel };
