import { PolymorphicComponent } from '../utils';
import { TablePaginationActionsTypeMap } from './TablePaginationActions.types';
/**
 * @ignore - internal component.
 */
declare const TablePaginationActions: PolymorphicComponent<TablePaginationActionsTypeMap<{}, "button">>;
export { TablePaginationActions };
