import { UseInputParameters, UseInputReturnValue } from './useInput.types';
/**
 *
 * Demos:
 *
 * - [Input](https://mui.com/base-ui/react-input/#hook)
 *
 * API:
 *
 * - [useInput API](https://mui.com/base-ui/react-input/hooks-api/#use-input)
 */
export declare function useInput(parameters?: UseInputParameters): UseInputReturnValue;
