import { PolymorphicComponent } from '../utils/PolymorphicComponent';
import { InputTypeMap } from './Input.types';
/**
 *
 * Demos:
 *
 * - [Input](https://mui.com/base-ui/react-input/)
 *
 * API:
 *
 * - [Input API](https://mui.com/base-ui/react-input/components-api/#input)
 */
declare const Input: PolymorphicComponent<InputTypeMap<{}, "div">>;
export { Input };
