import { UseModalParameters, UseModalReturnValue } from './useModal.types';
/**
 *
 * Demos:
 *
 * - [Modal](https://mui.com/base-ui/react-modal/#hook)
 *
 * API:
 *
 * - [useModal API](https://mui.com/base-ui/react-modal/hooks-api/#use-modal)
 */
export declare function useModal(parameters: UseModalParameters): UseModalReturnValue;
