import * as React from 'react';
import { PopupProps } from './Popup.types';
/**
 *
 * Demos:
 *
 * - [Popup](https://mui.com/base-ui/react-popup/)
 *
 * API:
 *
 * - [Popup API](https://mui.com/base-ui/react-popup/components-api/#popup)
 */
declare const Popup: React.ForwardRefExoticComponent<Omit<PopupProps<React.ElementType<any>>, "ref"> & React.RefAttributes<Element>>;
export { Popup };
