import { UseMenuButtonParameters, UseMenuButtonReturnValue } from './useMenuButton.types';
/**
 *
 * Demos:
 *
 * - [Menu](https://mui.com/base-ui/react-menu/#hooks)
 *
 * API:
 *
 * - [useMenuButton API](https://mui.com/base-ui/react-menu/hooks-api/#use-menu-button)
 */
export declare function useMenuButton(parameters?: UseMenuButtonParameters): UseMenuButtonReturnValue;
