import { PolymorphicComponent } from '../utils/PolymorphicComponent';
import { MenuTypeMap } from './Menu.types';
/**
 *
 * Demos:
 *
 * - [Menu](https://mui.com/base-ui/react-menu/)
 *
 * API:
 *
 * - [Menu API](https://mui.com/base-ui/react-menu/components-api/#menu)
 */
declare const Menu: PolymorphicComponent<MenuTypeMap<{}, "div">>;
export { Menu };
