import { PolymorphicComponent } from '../utils';
import { TabsTypeMap } from './Tabs.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/)
 *
 * API:
 *
 * - [Tabs API](https://mui.com/base-ui/react-tabs/components-api/#tabs)
 */
declare const Tabs: PolymorphicComponent<TabsTypeMap<{}, "div">>;
export { Tabs };
