import { UseTabsListParameters, UseTabsListReturnValue } from './useTabsList.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/#hooks)
 *
 * API:
 *
 * - [useTabsList API](https://mui.com/base-ui/react-tabs/hooks-api/#use-tabs-list)
 */
declare function useTabsList(parameters: UseTabsListParameters): UseTabsListReturnValue;
export { useTabsList };
