import { TabTypeMap } from './Tab.types';
import { PolymorphicComponent } from '../utils';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/)
 *
 * API:
 *
 * - [Tab API](https://mui.com/base-ui/react-tabs/components-api/#tab)
 */
declare const Tab: PolymorphicComponent<TabTypeMap<{}, "button">>;
export { Tab };
