import { PolymorphicComponent } from '../utils/PolymorphicComponent';
import { SliderTypeMap } from './Slider.types';
/**
 *
 * Demos:
 *
 * - [Slider](https://mui.com/base-ui/react-slider/)
 *
 * API:
 *
 * - [Slider API](https://mui.com/base-ui/react-slider/components-api/#slider)
 */
declare const Slider: PolymorphicComponent<SliderTypeMap<{}, "span">>;
export { Slider };
