import { UseTabParameters, UseTabReturnValue } from './useTab.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/#hooks)
 *
 * API:
 *
 * - [useTab API](https://mui.com/base-ui/react-tabs/hooks-api/#use-tab)
 */
declare function useTab(parameters: UseTabParameters): UseTabReturnValue;
export { useTab };
