import * as React from 'react';
import { DropdownProps } from './Dropdown.types';
/**
 *
 * Demos:
 *
 * - [Menu](https://mui.com/base-ui/react-menu/)
 *
 * API:
 *
 * - [Dropdown API](https://mui.com/base-ui/react-menu/components-api/#dropdown)
 */
declare function Dropdown(props: DropdownProps): React.JSX.Element;
declare namespace Dropdown {
    var propTypes: any;
}
export { Dropdown };
