import { PolymorphicComponent } from '../utils';
import { TabsListTypeMap } from './TabsList.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/)
 *
 * API:
 *
 * - [TabsList API](https://mui.com/base-ui/react-tabs/components-api/#tabs-list)
 */
declare const TabsList: PolymorphicComponent<TabsListTypeMap<{}, "div">>;
export { TabsList };
