import { UseMenuParameters, UseMenuReturnValue } from './useMenu.types';
/**
 *
 * Demos:
 *
 * - [Menu](https://mui.com/base-ui/react-menu/#hooks)
 *
 * API:
 *
 * - [useMenu API](https://mui.com/base-ui/react-menu/hooks-api/#use-menu)
 */
export declare function useMenu(parameters?: UseMenuParameters): UseMenuReturnValue;
