/**
 * Removes event handlers from the given object.
 * A field is considered an event handler if it is a function with a name beginning with `on`.
 *
 * @param object Object to remove event handlers from.
 * @returns Object with event handlers removed.
 */
export declare function omitEventHandlers<Props extends Record<string, unknown>>(object: Props | undefined): {};
