import * as React from 'react';
/**
 * Determines if a given element is a DOM element name (i.e. not a React component).
 */
export declare function isHostComponent(element: React.ElementType): boolean;
