import type { UseMenuItemParameters, UseMenuItemReturnValue } from './useMenuItem.types';
/**
 *
 * Demos:
 *
 * - [Menu](https://mui.com/base-ui/react-menu/#hooks)
 *
 * API:
 *
 * - [useMenuItem API](https://mui.com/base-ui/react-menu/hooks-api/#use-menu-item)
 */
export declare function useMenuItem(params: UseMenuItemParameters): UseMenuItemReturnValue;
