import { UseTabPanelParameters, UseTabPanelReturnValue } from './useTabPanel.types';
/**
 *
 * Demos:
 *
 * - [Tabs](https://mui.com/base-ui/react-tabs/#hooks)
 *
 * API:
 *
 * - [useTabPanel API](https://mui.com/base-ui/react-tabs/hooks-api/#use-tab-panel)
 */
declare function useTabPanel(parameters: UseTabPanelParameters): UseTabPanelReturnValue;
export { useTabPanel };
