import { UseSwitchParameters, UseSwitchReturnValue } from './useSwitch.types';
/**
 * The basic building block for creating custom switches.
 *
 * Demos:
 *
 * - [Switch](https://mui.com/base-ui/react-switch/#hook)
 *
 * API:
 *
 * - [useSwitch API](https://mui.com/base-ui/react-switch/hooks-api/#use-switch)
 */
export declare function useSwitch(props: UseSwitchParameters): UseSwitchReturnValue;
